/*
Copyright (c) Daybrush
name: vue-infinite-viewer
license: MIT
author: Daybrush
repository: https://github.com/daybrush/infinite-viewer/blob/master/packages/vue-infinite-viewer
version: 0.15.1
*/
import VanillaInfiniteViewer, { METHODS, OPTIONS, EVENTS, PROPERTIES } from 'infinite-viewer';
import { isUndefined } from '@daybrush/utils';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

var methods = {};
METHODS.forEach(function (name) {
  methods[name] = function () {
    var _a;

    var args = [];

    for (var _i = 0; _i < arguments.length; _i++) {
      args[_i] = arguments[_i];
    }

    return (_a = this.infiniteViewer)[name].apply(_a, args);
  };
});
var script = {
  name: "infinite-viewer",
  methods: methods,
  props: OPTIONS,
  mounted: function () {
    var _this = this;

    var options = {};
    var props = this.$props;
    OPTIONS.forEach(function (name) {
      var value = props[name];

      if (!isUndefined(value)) {
        options[name] = props[name];
      }
    });
    var refs = this.$refs;
    this.infiniteViewer = new VanillaInfiniteViewer(refs.containerElement, refs.scrollAreaElement.nextElementSibling, __assign(__assign({}, options), {
      wrapperElement: refs.wrapperElement,
      scrollAreaElement: refs.scrollAreaElement,
      horizontalScrollElement: refs.horizontalScrollElement,
      verticalScrollElement: refs.verticalScrollElement
    }));
    var infiniteViewer = this.infiniteViewer;
    EVENTS.forEach(function (name) {
      infiniteViewer.on(name, function (e) {
        _this.$emit(name, __assign({}, e));
      });
    });
  },
  updated: function () {
    var props = this.$props;
    var infiniteViewer = this.infiniteViewer;
    PROPERTIES.forEach(function (name) {
      var value = props[name];

      if (infiniteViewer[name] !== value && !isUndefined(value)) {
        infiniteViewer[name] = props[name];
      }
    });
  },
  beforeDestroy: function () {
    this.infiniteViewer.destroy();
  }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__ = script;
/* template */

var __vue_render__ = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c("div", {
    ref: "containerElement"
  }, [_c("div", {
    ref: "wrapperElement"
  }, [_c("div", {
    ref: "scrollAreaElement"
  }), _vm._v(" "), _vm._t("default")], 2), _vm._v(" "), _c("div", {
    ref: "horizontalScrollElement"
  }, [_c("div", {
    staticClass: "infinite-viewer-scroll-thumb"
  })]), _vm._v(" "), _c("div", {
    ref: "verticalScrollElement"
  }, [_c("div", {
    staticClass: "infinite-viewer-scroll-thumb"
  })])]);
};

var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;
/* style */

const __vue_inject_styles__ = undefined;
/* scoped */

const __vue_scope_id__ = undefined;
/* module identifier */

const __vue_module_identifier__ = undefined;
/* functional template */

const __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__ =
/*#__PURE__*/
normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

// import VueInfiniteViewer from './VueInfiniteViewer';

export default __vue_component__;
export { __vue_component__ as VueInfiniteViewer };
//# sourceMappingURL=infinite-viewer.esm.js.map
